@@ -1,9 +1,9 @@
 package BorderStyle::Test::Labeled;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-19'; # DATE
+our $DATE = '2021-01-23'; # DATE
 our $DIST = 'BorderStyleBase'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
@@ -12,14 +12,14 @@ use parent 'BorderStyleBase';
 our %BORDER = (
     v => 2,
     summary => 'A border style that uses labeled characters as described in specification, to show which character goes where',
-    chars => [                 # y
-        # 0    1    2    3 <-- x
-        ['A', 'b', 'C', 'D'],  # 0
-        ['E', 'F', 'G'],       # 1
-        ['H', 'i', 'J', 'K'],  # 2
-        ['L', 'M', 'N'],       # 3
-        ['O', 'p', 'Q', 'R'],  # 4
-        ['S', 't', 'U', 'V'],  # 5
+    chars => [                                     # y
+        # 0    1    2    3    4    5    6    7     <-- x
+        ['A', 'B', 'C', 'D'],                      # 0
+        ['E', 'F', 'G'],                           # 1
+        ['H', 'I', 'J', 'K', 'a', 'b'],            # 2
+        ['L', 'M', 'N'],                           # 3
+        ['O', 'P', 'Q', 'R', 'e', 'f', 'g', 'h'],  # 4
+        ['S', 'T', 'U', 'V'],                      # 5
     ],
 );
 
@@ -38,7 +38,7 @@ BorderStyle::Test::Labeled
 
 =head1 VERSION
 
-This document describes version 0.004 of BorderStyle::Test::Labeled (from Perl distribution BorderStyleBase), released on 2020-06-19.
+This document describes version 0.005 of BorderStyle::Test::Labeled (from Perl distribution BorderStyleBase), released on 2021-01-23.
 
 =head1 HOMEPAGE
 
@@ -50,7 +50,7 @@ Source repository is at L<https://github.com/perlancar/perl-BorderStyleBase>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=BorderStyleBase>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-BorderStyleBase/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -62,7 +62,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
